==> kendo-vue-notification-4.3.0-dev.202401301426.tgz: package/README.md <==
<a href="https://www.telerik.com/kendo-vue-ui/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-notification&utm_content=banner" target="_blank">
<img src="https://www.telerik.com/kendo-vue-ui/npm-banner.svg" alt="Kendo UI for Vue NPM Banner">
</a>

# Kendo UI for Vue Notification Component for Vue

> **Important**
> * This package is а part of [Kendo UI for Vue](https://www.telerik.com/kendo-vue-ui/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-notification)&mdash;a commercial UI library.
> * You will need to install a license key when adding the package to your project. For more information, please refer to the [Kendo UI for Vue My License page](https://www.telerik.com/kendo-vue-ui/my-license/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-notification).
> * To receive a license key, you need to either [purchase a license](https://www.telerik.com/purchase/kendo-ui/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-notification) or register for a [free trial](https://www.telerik.com/try/kendo-vue-ui?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-notification). Doing so indicates that you [accept the Kendo UI for Vue License Agreement](https://www.telerik.com/purchase/license-agreement/progress-kendovue?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-notification).
> * The 30-day free trial gives you access to all the Kendo UI for Vue components and their full functionality. Additionally, for the period of your license, you get access to our legendary technical support provided directly by the Kendo UI for Vue dev team!
>
> [Start using Kendo UI for Vue](https://www.telerik.com/try/kendo-vue-ui?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-notification) and speed up your development process!

The Kendo UI for Vue Notification renders a brief message to the user with information about the status of an application process and enables you to animate its rendering and control its position.

## Vue Notification

> Historically, all Kendo UI for Vue Native components support both **Vue 2** and **Vue 3**, however, Vue 2 is currently in its end-of-support phase till Nov 2024. After our last major release for 2024, Vue 2 will no longer be supported in the new versions of the Kendo UI for Vue components. Please check our [Vue 2 End of Support article](https://www.telerik.com/kendo-vue-ui/components/vue2-deprecation/) for more details.

Among the features which the Kendo UI for Vue Notification component delivers are:

* [Notification types](https://www.telerik.com/kendo-vue-ui/components/notification/types/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-notification)&mdash;Depending on the outcome of application operations and processes, the Notification enables you to display different types of notifications, like `info`, `error`, `warning`, and more.
* [Animations](https://www.telerik.com/kendo-vue-ui/components/notification/animations/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-notification)&mdash;The Notification allows you to add opening and closing animations to it by using the Kendo UI for Vue Animation components from the [@progress/kendo-vue-animation package](https://www.npmjs.com/package/@progress/kendo-vue-animation).
* [Positioning](https://www.telerik.com/kendo-vue-ui/components/notification/positioning/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-notification)&mdash;You can configure the position of the Notification through a property.
* [Theme support](https://www.telerik.com/kendo-vue-ui/components/styling/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-notification)&mdash;The Kendo UI for Vue Notification, as well as all 100+ components in the Kendo UI for Vue suite, are styled in three polished themes (Bootstrap, Material, and Default) and can be further customized to match your specific design guidelines.

## Support Options

For any issues you might encounter while working with the Kendo UI for Vue Notification, use any of the available support channels:

* Industry-leading technical support&mdash;Kendo UI for Vue paid license holders and users with an active (free) trial license can take advantage of our outstanding customer support. To submit a ticket, use [the dedicated Kendo UI for Vue support system](https://www.telerik.com/account/support-tickets?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-notification).
* Product forums&mdash;The [Kendo UI for Vue forums](https://www.telerik.com/forums/kendo-ui-vue?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-notification) are part of the free support you can get from the community and from the Kendo UI for Vue team.
* Feedback portal&mdash;The [Kendo UI for Vue feedback portal](https://feedback.telerik.com/kendo-vue-ui?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-notification) is where you can request and vote for new features to be added.

## Resources

* [Getting Started with Kendo UI for Vue](https://www.telerik.com/kendo-vue-ui/getting-started/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-notification)
* [Get Started with the Kendo UI for Vue Notification](https://www.telerik.com/kendo-vue-ui/components/notification/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-notification)
* [API Reference of the Kendo UI for Vue Notification](https://www.telerik.com/kendo-vue-ui/components/notification/api/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-notification)
* [Kendo UI for Vue Roadmap](https://www.telerik.com/support/whats-new/kendo-vue-ui/roadmap?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-notification)
* [Blogs](https://www.telerik.com/blogs/tag/vue?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-notification)
* [Demos, documentation, and component reference](https://www.telerik.com/kendo-vue-ui/components/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-notification)
* [Kendo UI for Vue pricing and licensing](https://www.telerik.com/purchase/kendo-ui/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-notification)
* [Changelog](https://www.telerik.com/kendo-vue-ui/components/changelogs/ui-for-vue/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-notification)

*Copyright © 2023 Progress Software Corporation and/or its subsidiaries or affiliates. All Rights Reserved.*

*Progress, Telerik, and certain product names used herein are trademarks or registered trademarks of Progress Software Corporation and/or one of its subsidiaries or affiliates in the U.S. and/or other countries.*

==> kendo-vue-notification-4.3.2-dev.202403200941.tgz: package/README.md <==
<a href="https://www.telerik.com/kendo-vue-ui/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-notification&utm_content=banner" target="_blank">
<img src="https://www.telerik.com/kendo-vue-ui/npm-banner.svg" alt="Kendo UI for Vue NPM Banner">
</a>

# Kendo UI for Vue Notification Component for Vue

> **Important**
> * This package is а part of [Kendo UI for Vue](https://www.telerik.com/kendo-vue-ui/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-notification)&mdash;a commercial UI library.
> * You will need to install a license key when adding the package to your project. For more information, please refer to the [Kendo UI for Vue My License page](https://www.telerik.com/kendo-vue-ui/my-license/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-notification).
> * To receive a license key, you need to either [purchase a license](https://www.telerik.com/purchase/kendo-ui/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-notification) or register for a [free trial](https://www.telerik.com/try/kendo-vue-ui?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-notification). Doing so indicates that you [accept the Kendo UI for Vue License Agreement](https://www.telerik.com/purchase/license-agreement/progress-kendovue?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-notification).
> * The 30-day free trial gives you access to all the Kendo UI for Vue components and their full functionality. Additionally, for the period of your license, you get access to our legendary technical support provided directly by the Kendo UI for Vue dev team!
>
> [Start using Kendo UI for Vue](https://www.telerik.com/try/kendo-vue-ui?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-notification) and speed up your development process!

The Kendo UI for Vue Notification renders a brief message to the user with information about the status of an application process and enables you to animate its rendering and control its position.

## Vue Notification

> Historically, all Kendo UI for Vue Native components support both **Vue 2** and **Vue 3**, however, Vue 2 is currently in its end-of-support phase till Nov 2024. After our last major release for 2024, Vue 2 will no longer be supported in the new versions of the Kendo UI for Vue components. Please check our [Vue 2 End of Support article](https://www.telerik.com/kendo-vue-ui/components/vue2-deprecation/) for more details.

Among the features which the Kendo UI for Vue Notification component delivers are:

* [Notification types](https://www.telerik.com/kendo-vue-ui/components/notification/types/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-notification)&mdash;Depending on the outcome of application operations and processes, the Notification enables you to display different types of notifications, like `info`, `error`, `warning`, and more.
* [Animations](https://www.telerik.com/kendo-vue-ui/components/notification/animations/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-notification)&mdash;The Notification allows you to add opening and closing animations to it by using the Kendo UI for Vue Animation components from the [@progress/kendo-vue-animation package](https://www.npmjs.com/package/@progress/kendo-vue-animation).
* [Positioning](https://www.telerik.com/kendo-vue-ui/components/notification/positioning/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-notification)&mdash;You can configure the position of the Notification through a property.
* [Theme support](https://www.telerik.com/kendo-vue-ui/components/styling/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-notification)&mdash;The Kendo UI for Vue Notification, as well as all 100+ components in the Kendo UI for Vue suite, are styled in four polished themes (Bootstrap, Material, Default and Fluent) and can be further customized to match your specific design guidelines.

## Support Options

For any issues you might encounter while working with the Kendo UI for Vue Notification, use any of the available support channels:

* Industry-leading technical support&mdash;Kendo UI for Vue paid license holders and users with an active (free) trial license can take advantage of our outstanding customer support. To submit a ticket, use [the dedicated Kendo UI for Vue support system](https://www.telerik.com/account/support-tickets?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-notification).
* Product forums&mdash;The [Kendo UI for Vue forums](https://www.telerik.com/forums/kendo-ui-vue?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-notification) are part of the free support you can get from the community and from the Kendo UI for Vue team.
* Feedback portal&mdash;The [Kendo UI for Vue feedback portal](https://feedback.telerik.com/kendo-vue-ui?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-notification) is where you can request and vote for new features to be added.

## Resources

* [Getting Started with Kendo UI for Vue](https://www.telerik.com/kendo-vue-ui/getting-started/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-notification)
* [Get Started with the Kendo UI for Vue Notification](https://www.telerik.com/kendo-vue-ui/components/notification/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-notification)
* [API Reference of the Kendo UI for Vue Notification](https://www.telerik.com/kendo-vue-ui/components/notification/api/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-notification)
* [Kendo UI for Vue Roadmap](https://www.telerik.com/support/whats-new/kendo-vue-ui/roadmap?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-notification)
* [Blogs](https://www.telerik.com/blogs/tag/vue?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-notification)
* [Demos, documentation, and component reference](https://www.telerik.com/kendo-vue-ui/components/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-notification)
* [Kendo UI for Vue pricing and licensing](https://www.telerik.com/purchase/kendo-ui/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-notification)
* [Changelog](https://www.telerik.com/kendo-vue-ui/components/changelogs/ui-for-vue/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-notification)

*Copyright © 2023 Progress Software Corporation and/or its subsidiaries or affiliates. All Rights Reserved.*

*Progress, Telerik, and certain product names used herein are trademarks or registered trademarks of Progress Software Corporation and/or one of its subsidiaries or affiliates in the U.S. and/or other countries.*
